@@ -10,7 +10,7 @@ UNAME_MACHINE=unknown
 CC="gcc -fPIC"
 CC="gcc -static"
 CC="gcc"
-CFLAGS="-Wall -Wno-uninitialized -O2 -fomit-frame-pointer"
+CFLAGS="-Wall -O2 -fomit-frame-pointer"
 
 # delete the next line to disable assembler support
 UNAME_MACHINE=`(uname -m) 2>/dev/null` || UNAME_MACHINE=unknown
