@@ -2,6 +2,12 @@
 
    This file is part of the LZO real-time data compression library.
 
+   Copyright (C) 2011 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2010 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2009 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2008 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2007 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2006 Markus Franz Xaver Johannes Oberhumer
    Copyright (C) 2005 Markus Franz Xaver Johannes Oberhumer
    Copyright (C) 2004 Markus Franz Xaver Johannes Oberhumer
    Copyright (C) 2003 Markus Franz Xaver Johannes Oberhumer
@@ -15,8 +21,9 @@
    All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License,
-   version 2, as published by the Free Software Foundation.
+   modify it under the terms of the GNU General Public License as
+   published by the Free Software Foundation; either version 2 of
+   the License, or (at your option) any later version.
 
    The LZO library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -80,7 +87,7 @@ int do_compress          ( const lzo_bytep in , lzo_uint  in_len,
     for (;;)
     {
         register const lzo_bytep m_pos;
-        lzo_uint m_off;
+        LZO_DEFINE_UNINITIALIZED_VAR(lzo_uint, m_off, 0);
         lzo_uint m_len;
         lzo_uint dindex;
         lzo_uint lit;
@@ -104,7 +111,7 @@ int do_compress          ( const lzo_bytep in , lzo_uint  in_len,
 
 try_match:
 #if 0 && defined(LZO_UNALIGNED_OK_2)
-        if (* (const lzo_ushortp) m_pos != * (const lzo_ushortp) ip)
+        if (UA_GET16(m_pos) != UA_GET16(ip))
 #else
         if (m_pos[0] != ip[0] || m_pos[1] != ip[1])
 #endif
@@ -278,7 +285,7 @@ lzo1f_1_compress ( const lzo_bytep in , lzo_uint  in_len,
     lzo_bytep op = out;
     int r = LZO_E_OK;
 
-    if (in_len <= 0)
+    if (in_len == 0)
         *out_len = 0;
     else if (in_len <= 10)
     {
@@ -292,9 +299,9 @@ lzo1f_1_compress ( const lzo_bytep in , lzo_uint  in_len,
     if (r == LZO_E_OK)
     {
         op = out + *out_len;
-        *op++ = M3_MARKER | 1;
-        *op++ = 0;
-        *op++ = 0;
+        op[0] = M3_MARKER | 1;
+        op[1] = 0;
+        op[2] = 0;
         *out_len += 3;
     }
 
