@@ -2,6 +2,12 @@
 
    This file is part of the LZO real-time data compression library.
 
+   Copyright (C) 2011 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2010 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2009 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2008 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2007 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2006 Markus Franz Xaver Johannes Oberhumer
    Copyright (C) 2005 Markus Franz Xaver Johannes Oberhumer
    Copyright (C) 2004 Markus Franz Xaver Johannes Oberhumer
    Copyright (C) 2003 Markus Franz Xaver Johannes Oberhumer
@@ -15,8 +21,9 @@
    All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License,
-   version 2, as published by the Free Software Foundation.
+   modify it under the terms of the GNU General Public License as
+   published by the Free Software Foundation; either version 2 of
+   the License, or (at your option) any later version.
 
    The LZO library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -41,12 +48,12 @@
 //
 ************************************************************************/
 
-#define N           16383           /* size of ring buffer */
-#define THRESHOLD       2           /* lower limit for match length */
-#define F            2048           /* upper limit for match length */
+#define SWD_N           16383           /* size of ring buffer */
+#define SWD_THRESHOLD       2           /* lower limit for match length */
+#define SWD_F            2048           /* upper limit for match length */
 
 
-#define LZO1F
+#define LZO1F 1
 #define LZO_COMPRESS_T  lzo1f_999_t
 #define lzo_swd_t       lzo1f_999_swd_t
 #include "lzo_mchw.ch"
@@ -217,7 +224,7 @@ lzo1f_999_compress_callback ( const lzo_bytep in , lzo_uint  in_len,
         if (m_len > 0 && lazy_match_min_gain >= 0 && c->look > m_len)
         {
             r = find_match(c,swd,1,0);
-            assert(r == 0);
+            assert(r == 0); LZO_UNUSED(r);
             assert(c->look > 0);
 
             if (m_len <= M2_MAX_LEN && m_off <= M2_MAX_OFFSET &&
@@ -268,7 +275,7 @@ lzo1f_999_compress_callback ( const lzo_bytep in , lzo_uint  in_len,
             /* a literal */
             lit++;
             r = find_match(c,swd,1,0);
-            assert(r == 0);
+            assert(r == 0); LZO_UNUSED(r);
         }
         else
         {
@@ -286,7 +293,7 @@ lzo1f_999_compress_callback ( const lzo_bytep in , lzo_uint  in_len,
             /* 2 - code match */
             op = code_match(c,op,m_len,m_off);
             r = find_match(c,swd,m_len,1+ahead);
-            assert(r == 0);
+            assert(r == 0); LZO_UNUSED(r);
         }
 
         c->codesize = pd(op, out);
